pub struct BasicSpinMutexGuard<'a, T, const PAUSE: bool> { /* private fields */ }Expand description
A guard providing access to the data protected by a BasicSpinMutex.
The lock is automatically released when this guard is dropped.
Implementations
Sourceimpl<'a, T, const PAUSE: bool> BasicSpinMutexGuard<'a, T, PAUSE>
impl<'a, T, const PAUSE: bool> BasicSpinMutexGuard<'a, T, PAUSE>